==> nap-1.4.4.tar.gz: nap-1.4.4/codes.h <==
#define F_LOGERROR 0x0
#define F_LOGIN 0x2
#define F_LOGSUCCESS 0x3
#define F_REG 0x6
#define F_MKUSER 0x7
#define F_UNOK 0x8
#define F_UNTK 0x9
#define F_UNBAD 0xa
#define F_SFILE 0x64
#define F_DFILE 0x66
#define F_WHOIS 0x25b
#define F_SWHOIS 0x25c
#define F_SOFF 0x25d
#define F_NOTICE 0x26d
#define F_GFR 0x260
#define F_FREQ 0x25f
#define F_COUNT 0xd6
#define F_TELL 0xcd
#define F_JOIN 0x190
#define F_PART 0x191
#define F_SAY 0x192
#define F_SAID 0x193
#define F_NCHAN 0x194
#define F_JCHAN 0x195
#define F_SJOIN 0x196
#define F_SPART 0x197
#define F_USER 0x198
#define F_MNAME 0x199
#define F_MNAME2 0x33e
#define F_TOPIC 0x19a
#define F_SGET 0xcc
#define F_DGET 0xcb
#define F_NGET 0xce
#define F_BROWSE 0xd3
#define F_RBROWSE 0xd4
#define F_DBROWSE 0xd5
#define F_SX 0x258
#define F_RY 0x259
#define F_DSF 0x1f4
#define F_SSF 0x1f5
#define F_UON 0xd1
#define F_UOFF 0xd2
#define F_NOTIFY 0xcf
#define F_RNOTIFY 0x12f
#define F_SUON 0x12d
#define F_SUERR 0x12e
#define F_SEARCH 0xc8
#define F_SSEARCH 0xc9
#define F_KILL 0x262
#define F_NUKE 0x263
#define F_UNNUKE 0x270
#define F_BAN 0x264
#define F_UNBAN 0x266
#define F_DATAP 0x265
#define F_LEVEL 0x25e
#define F_SRET 0xc9
#define F_SEND 0xca
#define F_SOP 0x273
#define F_ANNOUNCE 0x274
#define F_PCHANGE 0x265
#define F_BPORT 0x272
#define F_DBANLIST 0x267
#define F_SBANLIST 0x268
#define F_SBANLISTU 0x275
#define F_MISCONFIGURE 0x272
#define F_LSCHANGE 0x271
#define F_MUZZLE 0x26e
#define F_UNMUZZLE 0x26f
#define F_CLIST 0x269
#define F_SCLIST 0x26a
#define F_NAMES 0x339
#define F_UP 0xdc
#define F_UPDONE 0xdd
#define F_DOWN 0xda
#define F_DOWNDONE 0xdb
#define F_CLOAK 0x28c
#define F_BLOCKLIST 0x14a
#define F_SBLOCKLIST 0x14b
#define F_BLOCK 0x14c
#define F_UNBLOCK 0x14d
#define F_QLIMIT 0x26b

#define SERVER_PING 0x2ee
#define CLIENT_PING 0x2ef
#define CLIENT_PONG 0x2f0

#define SET_USER_PASSWORD 0x2f1
#define SERVER_RELOAD_CONFIG 0x320
#define SERVER_VERSION 0x321
#define SERVER_SET_CONFIG 0x32a

#define CHANNEL_CLEAR 0x334
#define CHANNEL_SETLEVEL 0x337
#define CHAN_EMOTE 824

#define CLIENT_REDIRECT 0x335
#define CLIENT_CYCLE 0x336

#define CHANNEL_USERLIST 0x33e
#define SERVER_USERLIST 0x33f

#define IGNORE_LIST 320
#define IGNORE_ENTRY 321
#define IGNORE_ADD 322
#define IGNORE_REMOVE 323
#define IGNORE_UNKNOWN 324
#define IGNORE_EXISTS 325
#define IGNORE_CLEAR 326
#define IGNORE_FAIL 327

#define CHANNEL_KICK 829
#define CHANNEL_BAN_LIST 420
#define CHANNEL_BAN_ENTRY 421
#define CHANNEL_BAN_ADD 422
#define CHANNEL_BAN_REMOVE 423
#define CHANNEL_BAN_CLEAR 424

#define CHANNEL_LIST2 827
#define CHANNEL_ENTRY2 828

#define ADD_NOTIFY 207
#define NOTIFY_CHECK 208
#define NOTIFY_EXISTS 301
#define NOTIFY_UNKNOWN 302
#define REMOVE_NOTIFY 303

#define CHANNEL_MOTD 425

==> nap-1.4.5.tar.gz: nap-1.4.5/codes.h <==
#define F_LOGERROR 0x0
#define F_LOGIN 0x2
#define F_LOGSUCCESS 0x3
/* 0x4 version check [CLIENT] */
/* 0x5 "auto-upgrade" [SERVER] */
#define F_REG 0x6
#define F_MKUSER 0x7
#define F_UNOK 0x8
#define F_UNTK 0x9
#define F_UNBAD 0xa
#define F_SFILE 0x64
#define F_DFILE 0x66
#define F_UNSHARE 0x6e /* unshare all files [CLIENT] */
#define F_SEARCH 0xc8
#define F_SSEARCH 0xc9
#define F_SRET 0xc9
/* two names for 0xc9? */
#define F_SEND 0xca
#define F_DGET 0xcb
#define F_SGET 0xcc
#define F_TELL 0xcd
#define F_NGET 0xce
/* 0xcf-0xd0 (207-208) also #defined below */
#define F_NOTIFY 0xcf
/* 0xd0 hotlist [CLIENT] */
#define F_UON 0xd1
#define F_UOFF 0xd2
#define F_BROWSE 0xd3
#define F_RBROWSE 0xd4
#define F_DBROWSE 0xd5
#define F_COUNT 0xd6
/* 0xd7 request resume [CLIENT] */
/* 0xd8 resume search response [SERVER] */
/* 0xd9 end of resume search list [SERVER] */
#define F_DOWN 0xda
#define F_DOWNDONE 0xdb
#define F_UP 0xdc
#define F_UPDONE 0xdd
/* 0x12c optional ports [CLIENT] */
/* 0x12d-0x12f (301-303) also #defined below */
#define F_SUON 0x12d
#define F_SUERR 0x12e
#define F_RNOTIFY 0x12f
/* 0x140-0x147 (320-327) see below for #defines */
#define F_BLOCKLIST 0x14a
#define F_SBLOCKLIST 0x14b
/* 0x14b not in spec? */
#define F_BLOCK 0x14c
#define F_UNBLOCK 0x14d
#define F_JOIN 0x190
#define F_PART 0x191
#define F_SAY 0x192
#define F_SAID 0x193
#define F_NCHAN 0x194
#define F_JCHAN 0x195
#define F_SJOIN 0x196
#define F_SPART 0x197
#define F_USER 0x198
#define F_MNAME 0x199
#define F_TOPIC 0x19a
/* 0x1a4-0x1a9 (420-425) see below for #defines */
#define F_DSF 0x1f4
#define F_SSF 0x1f5
#define F_SX 0x258
#define F_RY 0x259
#define F_WHOIS 0x25b
#define F_SWHOIS 0x25c
#define F_SOFF 0x25d
#define F_LEVEL 0x25e
#define F_FREQ 0x25f
#define F_GFR 0x260
/* 0x261 accept failed [SERVER] */
#define F_NACC 0x261
#define F_KILL 0x262
#define F_NUKE 0x263
#define F_BAN 0x264
#define F_DATAP 0x265
#define F_PCHANGE 0x265
/* two names for 0x265 ? */
#define F_UNBAN 0x266
#define F_DBANLIST 0x267
#define F_SBANLIST 0x268
#define F_CLIST 0x269
#define F_SCLIST 0x26a
#define F_QLIMIT 0x26b
/* 0x26c queue limit [SERVER] */
#define F_RQLIMIT 0x26c
#define F_NOTICE 0x26d
#define F_MUZZLE 0x26e
#define F_UNMUZZLE 0x26f
#define F_UNNUKE 0x270
#define F_LSCHANGE 0x271
#define F_MISCONFIGURE 0x272
#define F_BPORT 0x272
#define F_SOP 0x273
#define F_ANNOUNCE 0x274
#define F_SBANLISTU 0x275
/* 0x280-0x282 (640-642) direct browse */
#define F_CLOAK 0x28c
/* 0x2bc-0x2bf (700-703) change linkspeed/pw/e-mail/dataport */
/* 0x2ec (748) login attempt [SERVER] */
#define SERVER_PING 0x2ee
#define CLIENT_PING 0x2ef
#define CLIENT_PONG 0x2f0
#define SET_USER_PASSWORD 0x2f1

#define SERVER_RELOAD_CONFIG 0x320
#define SERVER_VERSION 0x321
#define SERVER_SET_CONFIG 0x32a

#define CHANNEL_CLEAR 0x334
#define CLIENT_REDIRECT 0x335
#define CLIENT_CYCLE 0x336
#define CHANNEL_SETLEVEL 0x337
/* 0x338 (824) */
#define CHAN_EMOTE 824
#define F_NAMES 0x339
/* 0x33a channel limit [CLIENT] */
/* 0x33b-0x33d (827-829) see below for #defines */
#define F_MNAME2 0x33e
#define CHANNEL_USERLIST 0x33e
/* two names for 0x33e ? */
#define SERVER_USERLIST 0x33f
/* 0x366 (870) add files by directory [CLIENT] */
/* 0x384-0x385 (900-901) connect/listen test [SERVER] */

/* 0x140-0x147 */
#define IGNORE_LIST 320
#define IGNORE_ENTRY 321
#define IGNORE_ADD 322
#define IGNORE_REMOVE 323
#define IGNORE_UNKNOWN 324
#define IGNORE_EXISTS 325
#define IGNORE_CLEAR 326
#define IGNORE_FAIL 327

/* 0x1a4-0x1a9 */
#define CHANNEL_BAN_LIST 420
#define CHANNEL_BAN_ENTRY 421
#define CHANNEL_BAN_ADD 422
#define CHANNEL_BAN_REMOVE 423
#define CHANNEL_BAN_CLEAR 424
#define CHANNEL_MOTD 425

/* 0x33b-0x33d */
#define CHANNEL_LIST2 827
#define CHANNEL_ENTRY2 828
#define CHANNEL_KICK 829

/* 0xcf-0xd0 */
#define ADD_NOTIFY 207
#define NOTIFY_CHECK 208
/* 0x12d-0x12f */
#define NOTIFY_EXISTS 301
#define NOTIFY_UNKNOWN 302
#define REMOVE_NOTIFY 303
